@@ -85,11 +85,14 @@ shading_hsv <- function(observed, residuals = NULL, expected = NULL, df = NULL,
     }
     dim(col) <- dim(x)
 
-    lty <- ifelse(x > 0, lty[1], lty[2])
-    dim(lty) <- dim(x)
-
-    return(structure(list(col = col, fill = fill, lty = lty), class = "gpar"))
-  }
+	# line type should be solid if abs(resid) < eps
+	ltytmp <- ifelse(x > 0, lty[1], lty[2])
+	if(!is.null(eps))
+		ltytmp[abs(x) < abs(eps)] <- lty[1]
+	dim(ltytmp) <- dim(x)
+	
+	return(structure(list(col = col, fill = fill, lty = ltytmp), class = "gpar"))
+}
   attr(rval, "legend") <- legend
   attr(rval, "p.value") <- p.value
   return(rval)
